/*******************************************************************\

Module: Jsil Language

Author: Michael Tautschnig, tautschn@amazon.com

\*******************************************************************/

/// \file
/// Jsil Language

#ifndef CPROVER_JSIL_JSIL_INTERNAL_ADDITIONS_H
#define CPROVER_JSIL_JSIL_INTERNAL_ADDITIONS_H

class symbol_tablet;

void jsil_internal_additions(symbol_tablet &dest);

#endif // CPROVER_JSIL_JSIL_INTERNAL_ADDITIONS_H
